pub struct ProcessOutput {
pub return_code: i64,
pub stderr: Vec<u8>,
pub stdout: Vec<u8>,
}Expand description
A struct to contain the results of a shell process.
Fields
return_code: i64The return code from a process.
stderr: Vec<u8>The stderr text output of a process.
stdout: Vec<u8>The stdout text output of a process.
Implementations
Sourceimpl ProcessOutput
impl ProcessOutput
Sourcepub fn return_code(&self) -> i64
pub fn return_code(&self) -> i64
The return code with which a process ended.
Sourcepub fn stdout_str(&self) -> &str
pub fn stdout_str(&self) -> &str
The stdout text output of a process, as a &str.
Sourcepub fn stderr_str(&self) -> &str
pub fn stderr_str(&self) -> &str
The stderr text output of a process, as a &str.